----------------------------------------------------------------------------------------------------
-- DotFocus
-- Author: Snowcloud (Mich - Antonidas)
-- Codebase by: Meranannon (Insane - Vol'jin)
----------------------------------------------------------------------------------------------------

-- namespace
local DOF = DOF_namespace
local DF = DF_namespace

local DFImpEventFrame = CreateFrame("FRAME","DFFeventFrame",UIParent)

function setUp()
  DOF_namespace.importerAvailable = true
  DFImpEventFrame:RegisterEvent("PLAYER_ENTERING_WORLD")
  DFImpEventFrame:SetScript("OnEvent", DFImpEventHandler)
  SLASH_DROODFOCUSIMPORTER1 = '/dfimport'
end

function DFImpEventHandler(self, eventArg, ...)
  if(eventArg == "PLAYER_ENTERING_WORLD") then
  
    DEFAULT_CHAT_FRAME:AddMessage("DotFocus - DroodFocus importer loaded!")
    DEFAULT_CHAT_FRAME:AddMessage("This importer only imports the currently active config from DroodFocus!")
    DEFAULT_CHAT_FRAME:AddMessage("If you have more than one DroodFocus configuration you have to use the original DroodFocus to switch them to the currently active one!")
    DEFAULT_CHAT_FRAME:AddMessage("Your interface will be automatically reloaded after the import.")
    DEFAULT_CHAT_FRAME:AddMessage("Look at the addon website for instructions! https://mods.curse.com/addons/wow/dotfocus !")
    DEFAULT_CHAT_FRAME:AddMessage("Start the import process by typing '/dfimport' in the chat.")

    if (DF~=nil) then
      DEFAULT_CHAT_FRAME:AddMessage("You have both DotFocus and the full version of DroodFocus installed. This is not working! Deactivate DroodFocus for the import!")
      return;
    end
  end
end

function SlashCmdList.DROODFOCUSIMPORTER(msg, editbox)
  DOF_namespace:import_DoImport()
end

function DOF_namespace:import_DoImport()
  local srcConfig
  local targetConfig
  local conf
  local i

  if (DOF==nil) then
      DEFAULT_CHAT_FRAME:AddMessage("DotFocus-Importer: You don't have DotFocus loaded! Retry with DotFocus loaded!")
      return;
  end

  if (not DF_saved_configs) or (not DF_config) then
    DEFAULT_CHAT_FRAME:AddMessage("DotFocus-Importer: DroodFocus config not found! Look at the addon website for instructions! https://mods.curse.com/addons/wow/dotfocus !")
    return 0;
  end
  
  srcConfig = DF_config.configname
  targetConfig = srcConfig.." (DF import)"

  DEFAULT_CHAT_FRAME:AddMessage("DroodFocus found! Importing config '"..srcConfig.."' as '"..targetConfig.."'")
  
  --DOF_saved_configs = DF_saved_configs
  DOF_config = DF_config
  DOF_config.configname = targetConfig 
  
  -- fix lua errors in spells (rename namespace)
  local nbSpells = getn(DOF_config.spells)
  local sp
  local luaCode
  for sp = 1,nbSpells do
    if DOF_config.spells[sp].luaCode~="" then
      luaCode = DOF_config.spells[sp].luaCode
      luaCode = DOF_namespace:dec64(DOF_namespace.luaList[1].code)
      
      string.gsub(luaCode, "DF_namespace", "DOF_namespace")
      
      luaCode = DOF_namespace:enc64(DOF_namespace.luaList[1].code)
      DOF_config.spells[sp].luaCode = luaCode
    end
    
    if DOF_config.spells[sp].FX_texture ~="" then
      DOF_config.spells[sp].FX_texture = DOF_namespace:fix_Texture_Path_String(DOF_config.spells[sp].FX_texture)
    end
    if DOF_config.spells[sp].FX_fontPath ~="" then
      DOF_config.spells[sp].FX_fontPath = DOF_namespace:fix_Texture_Path_String(DOF_config.spells[sp].FX_fontPath)
    end
    if DOF_config.spells[sp].abiSoundWarningFile ~="" then
      DOF_config.spells[sp].abiSoundWarningFile = DOF_namespace:fix_Texture_Path_String(DOF_config.spells[sp].abiSoundWarningFile)
    end
  end
  
  -- fix path names in texture settings
  if (DOF_config.portrait ~= null) then
    DOF_namespace:fix_Texture_Path_Array(DOF_config.portrait.textures)
  end
  if (DOF_config.powerbar ~= null) then
    DOF_config.powerbar.texturePath = DOF_namespace:fix_Texture_Path_String(DOF_config.powerbar.texturePath)
    DOF_config.powerbar.fontPath = DOF_namespace:fix_Texture_Path_String(DOF_config.powerbar.fontPath)
  end
  if (DOF_config.threatbar ~= null) then
    DOF_config.threatbar.texturePath = DOF_namespace:fix_Texture_Path_String(DOF_config.threatbar.texturePath)
    DOF_config.threatbar.fontPath = DOF_namespace:fix_Texture_Path_String(DOF_config.threatbar.fontPath)
  end
  if (DOF_config.alert ~= null) then
    DOF_config.alert.texture1 = DOF_namespace:fix_Texture_Path_String(DOF_config.alert.texture1)
    DOF_config.alert.texture2 = DOF_namespace:fix_Texture_Path_String(DOF_config.alert.texture2)
    DOF_config.alert.texture3 = DOF_namespace:fix_Texture_Path_String(DOF_config.alert.texture3)
    DOF_config.alert.fontPath = DOF_namespace:fix_Texture_Path_String(DOF_config.alert.fontPath)
  end
  if (DOF_config.dotPower ~= null) then
    DOF_config.dotPower.bigdotsTexture = DOF_namespace:fix_Texture_Path_String(DOF_config.alert.bigdotsTexture)
  end
  if (DOF_config.healthbar ~= null) then
    DOF_config.healthbar.texturePath = DOF_namespace:fix_Texture_Path_String(DOF_config.healthbar.texturePath)
    DOF_config.healthbar.fontPath = DOF_namespace:fix_Texture_Path_String(DOF_config.healthbar.fontPath)
  end
  if (DOF_config.iconbars ~= null) then
    for i = 1, getn(DOF_config.iconbars) do
      if (DOF_config.iconbars[i] ~= nil) then
        DOF_config.iconbars[i].fontPath = DOF_namespace:fix_Texture_Path_String(DOF_config.iconbars[i].fontPath)
      end
    end
  end
  if (DOF_config.defense ~= null) then
    DOF_namespace:fix_Texture_Path_Array(DOF_config.defense.textures)
    DOF_config.defense.texturePath = DOF_namespace:fix_Texture_Path_String(DOF_config.defense.texturePath)
    DOF_config.defense.fontPath = DOF_namespace:fix_Texture_Path_String(DOF_config.defense.fontPath)
  end
  if (DOF_config.anchor0 ~= null) then
    DOF_config.anchor0.texture = DOF_namespace:fix_Texture_Path_String(DOF_config.anchor0.texture)
  end
  if (DOF_config.anchor1 ~= null) then
    DOF_config.anchor1.texture = DOF_namespace:fix_Texture_Path_String(DOF_config.anchor1.texture)
  end
  if (DOF_config.anchor2 ~= null) then
    DOF_config.anchor2.texture = DOF_namespace:fix_Texture_Path_String(DOF_config.anchor2.texture)
  end
  if (DOF_config.anchor3 ~= null) then
    DOF_config.anchor3.texture = DOF_namespace:fix_Texture_Path_String(DOF_config.anchor3.texture)
  end
  if (DOF_config.anchor4 ~= null) then
    DOF_config.anchor4.texture = DOF_namespace:fix_Texture_Path_String(DOF_config.anchor4.texture)
  end
  if (DOF_config.anchor5 ~= null) then
    DOF_config.anchor5.texture = DOF_namespace:fix_Texture_Path_String(DOF_config.anchor5.texture)
  end
  if (DOF_config.anchor6 ~= null) then
    DOF_config.anchor6.texture = DOF_namespace:fix_Texture_Path_String(DOF_config.anchor6.texture)
  end
  if (DOF_config.anchor7 ~= null) then
    DOF_config.anchor7.texture = DOF_namespace:fix_Texture_Path_String(DOF_config.anchor7.texture)
  end
  if (DOF_config.anchor8 ~= null) then
    DOF_config.anchor8.texture = DOF_namespace:fix_Texture_Path_String(DOF_config.anchor8.texture)
  end
  if (DOF_config.icons ~= null) then
    DOF_config.icons.fontPath = DOF_namespace:fix_Texture_Path_String(DOF_config.icons.fontPath)
  end
  if (DOF_config.ooc ~= null) then
    DOF_config.ooc.textureOff = DOF_namespace:fix_Texture_Path_String(DOF_config.ooc.textureOff)
    DOF_config.ooc.textureOn = DOF_namespace:fix_Texture_Path_String(DOF_config.ooc.textureOn)
  end
  if (DOF_config.petbar ~= null) then
    DOF_config.petbar.texturePath = DOF_namespace:fix_Texture_Path_String(DOF_config.petbar.texturePath)
    DOF_config.petbar.fontPath = DOF_namespace:fix_Texture_Path_String(DOF_config.petbar.fontPath)
  end
  if (DOF_config.combo ~= null) then
    DOF_config.combo.texturePath = DOF_namespace:fix_Texture_Path_String(DOF_config.combo.texturePath)
    DOF_config.combo.fontPath = DOF_namespace:fix_Texture_Path_String(DOF_config.combo.fontPath)
    DOF_namespace:fix_Texture_Path_Array(DOF_config.combo.textures)
  end
  if (DOF_config.targetbar ~= null) then
    DOF_config.targetbar.texturePath = DOF_namespace:fix_Texture_Path_String(DOF_config.targetbar.texturePath)
    DOF_config.targetbar.fontPath = DOF_namespace:fix_Texture_Path_String(DOF_config.targetbar.fontPath)
  end
  if (DOF_config.timerbars ~= null) then
    for i = 1, getn(DOF_config.timerbars) do
      if (DOF_config.timerbars[i] ~= nil) then
        DOF_config.timerbars[i].font1Path = DOF_namespace:fix_Texture_Path_String(DOF_config.timerbars[i].font1Path)
        DOF_config.timerbars[i].font2Path = DOF_namespace:fix_Texture_Path_String(DOF_config.timerbars[i].font2Path)
        DOF_config.timerbars[i].texturePath = DOF_namespace:fix_Texture_Path_String(DOF_config.timerbars[i].texturePath)
      end
    end
  end
  if (DOF_config.timerbar ~= null) then
    DOF_config.timerbar.font1Path = DOF_namespace:fix_Texture_Path_String(DOF_config.timerbar.font1Path)
    DOF_config.timerbar.font2Path = DOF_namespace:fix_Texture_Path_String(DOF_config.timerbar.font2Path)
    DOF_config.timerbar.texturePath = DOF_namespace:fix_Texture_Path_String(DOF_config.timerbar.texturePath)
  end
  if (DOF_config.gps ~= null) then
    DOF_config.gps.fontPath = DOF_namespace:fix_Texture_Path_String(DOF_config.gps.fontPath)
  end
  if (DOF_config.defensebar ~= null) then
    DOF_config.defensebar.texturePath = DOF_namespace:fix_Texture_Path_String(DOF_config.defensebar.texturePath)
    DOF_config.defensebar.fontPath = DOF_namespace:fix_Texture_Path_String(DOF_config.defensebar.fontPath)
  end
  if (DOF_config.castbar ~= null) then
    DOF_config.castbar.texturePath = DOF_namespace:fix_Texture_Path_String(DOF_config.castbar.texturePath)
    DOF_config.castbar.fontPath = DOF_namespace:fix_Texture_Path_String(DOF_config.castbar.fontPath)
    DOF_config.castbar.fontPathtimer = DOF_namespace:fix_Texture_Path_String(DOF_config.castbar.fontPathtimer)
  end
  if (DOF_config.manabar ~= null) then
    DOF_config.manabar.texturePath = DOF_namespace:fix_Texture_Path_String(DOF_config.manabar.texturePath)
    DOF_config.manabar.fontPath = DOF_namespace:fix_Texture_Path_String(DOF_config.manabar.fontPath)
  end
  if (DOF_config.infos ~= null) then
    DOF_config.infos.fontPath = DOF_namespace:fix_Texture_Path_String(DOF_config.infos.fontPath)
  end
  if (DOF_config.eclipsebar ~= null) then
    DOF_config.eclipsebar.texturePath = DOF_namespace:fix_Texture_Path_String(DOF_config.eclipsebar.texturePath)
    DOF_config.eclipsebar.fontPath = DOF_namespace:fix_Texture_Path_String(DOF_config.eclipsebar.fontPath)
  end
      
  ReloadUI();  

end

function DOF_namespace:fix_Texture_Path_Array(array)
  local i
  for i = 1, getn(array) do
    if (array[i] ~= nil) then
      array[i] = DOF_namespace:fix_Texture_Path_String(array[i])
    end
  end
end

function DOF_namespace:fix_Texture_Path_String(str)
  if (str ~= nil) then
    return string.gsub(str, "DroodFocus", "DotFocus")
  end
  return nil
end

setUp()